You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by fs...@apache.org on 2017/02/19 15:45:34 UTC

svn commit: r1783653 - /jmeter/trunk/src/core/org/apache/jmeter/util/XPathUtil.java

Author: fschumacher
Date: Sun Feb 19 15:45:34 2017
New Revision: 1783653

URL: http://svn.apache.org/viewvc?rev=1783653&view=rev
Log:
Rename parameter to comply with java conventions.

Modified:
    jmeter/trunk/src/core/org/apache/jmeter/util/XPathUtil.java

Modified: jmeter/trunk/src/core/org/apache/jmeter/util/XPathUtil.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/util/XPathUtil.java?rev=1783653&r1=1783652&r2=1783653&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/util/XPathUtil.java (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/util/XPathUtil.java Sun Feb 19 15:45:34 2017
@@ -131,7 +131,7 @@ public class XPathUtil {
      * @param tolerant - Is tolerant - i.e. use the Tidy parser
      * @param quiet - set Tidy quiet
      * @param showWarnings - set Tidy warnings
      * @param report_errors - throw TidyException if Tidy detects an error
      * @param isXml - is document already XML (Tidy only)
      * @param downloadDTDs - if true, try to download external DTDs
      * @return document
@@ -141,10 +141,10 @@ public class XPathUtil {
      * @throws TidyException if a ParseError is detected and <code>report_errors</code> is <code>true</code>
      */
     public static Document makeDocument(InputStream stream, boolean validate, boolean whitespace, boolean namespace,
-            boolean tolerant, boolean quiet, boolean showWarnings, boolean report_errors, boolean isXml, boolean downloadDTDs)
+            boolean tolerant, boolean quiet, boolean showWarnings, boolean reportErrors, boolean isXml, boolean downloadDTDs)
             throws ParserConfigurationException, SAXException, IOException, TidyException {
         return makeDocument(stream, validate, whitespace, namespace,
-                tolerant, quiet, showWarnings, report_errors, isXml, downloadDTDs, null);
+                tolerant, quiet, showWarnings, reportErrors, isXml, downloadDTDs, null);
     }
 
     /**
@@ -131,7 +131,7 @@ public class XPathUtil {
      * @param quiet - set Tidy quiet
      * @param showWarnings - set Tidy warnings
-     * @param report_errors - throw TidyException if Tidy detects an error
+     * @param reportErrors - throw TidyException if Tidy detects an error
      * @param isXml - is document already XML (Tidy only)
      * @param downloadDTDs - if true, try to download external DTDs